@@ -1,6 +1,6 @@
 ;;; tramp-ftp.el --- Tramp convenience functions for Ange-FTP  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2002-2019 Free Software Foundation, Inc.
+;; Copyright (C) 2002-2020 Free Software Foundation, Inc.
 
 ;; Author: Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, processes
@@ -33,7 +33,6 @@
 ;; Pacify byte-compiler.
 (eval-when-compile
   (require 'custom))
-(declare-function ange-ftp-ftp-process-buffer "ange-ftp")
 (defvar ange-ftp-ftp-name-arg)
 (defvar ange-ftp-ftp-name-res)
 (defvar ange-ftp-name-format)
@@ -128,16 +127,7 @@ pass to the OPERATION."
 	  ;; "ftp" method is used in the Tramp file name. So we unset
 	  ;; those values.
 	  (ange-ftp-ftp-name-arg "")
-	  (ange-ftp-ftp-name-res nil)
-	  (v (tramp-dissect-file-name
-	      (apply #'tramp-file-name-for-operation operation args) t)))
-      (setf (tramp-file-name-method v) tramp-ftp-method)
-      ;; Set "process-name" for thread support.
-      (tramp-set-connection-property
-       v "process-name"
-       (ange-ftp-ftp-process-buffer
-	(tramp-file-name-host v) (tramp-file-name-user v)))
-
+	  (ange-ftp-ftp-name-res nil))
       (cond
        ;; If argument is a symlink, `file-directory-p' and
        ;; `file-exists-p' call the traversed file recursively. So we
@@ -149,7 +139,9 @@ pass to the OPERATION."
        ;; "~/.netrc".
        ((memq operation '(file-directory-p file-exists-p))
 	(if (apply #'ange-ftp-hook-function operation args)
-	    (tramp-set-connection-property v "started" t)
+	    (let ((v (tramp-dissect-file-name (car args) t)))
+	      (setf (tramp-file-name-method v) tramp-ftp-method)
+	      (tramp-set-connection-property v "started" t))
 	  nil))
 
        ;; If the second argument of `copy-file' or `rename-file' is a
